package com.zhyc.module.dairyProducts.service;

import java.util.List;

import com.zhyc.module.dairyProducts.domain.NpYogurtInsp;

/**
 * 酸奶生产，成品检疫记录Service接口
 * 
 * @author ruoyi
 * @date 2025-07-17
 */
public interface INpYogurtInspService 
{
    /**
     * 查询酸奶生产，成品检疫记录
     * 
     * @param id 酸奶生产，成品检疫记录主键
     * @return 酸奶生产，成品检疫记录
     */
    public NpYogurtInsp selectNpYogurtInspById(Long id);

    /**
     * 查询酸奶生产，成品检疫记录列表
     * 
     * @param npYogurtInsp 酸奶生产，成品检疫记录
     * @return 酸奶生产，成品检疫记录集合
     */
    public List<NpYogurtInsp> selectNpYogurtInspList(NpYogurtInsp npYogurtInsp);

    /**
     * 新增酸奶生产，成品检疫记录
     * 
     * @param npYogurtInsp 酸奶生产，成品检疫记录
     * @return 结果
     */
    public int insertNpYogurtInsp(NpYogurtInsp npYogurtInsp);

    /**
     * 修改酸奶生产，成品检疫记录
     * 
     * @param npYogurtInsp 酸奶生产，成品检疫记录
     * @return 结果
     */
    public int updateNpYogurtInsp(NpYogurtInsp npYogurtInsp);

    /**
     * 批量删除酸奶生产，成品检疫记录
     * 
     * @param ids 需要删除的酸奶生产，成品检疫记录主键集合
     * @return 结果
     */
    public int deleteNpYogurtInspByIds(Long[] ids);

    /**
     * 删除酸奶生产，成品检疫记录信息
     * 
     * @param id 酸奶生产，成品检疫记录主键
     * @return 结果
     */
    public int deleteNpYogurtInspById(Long id);
}
